@@ -8,3 +8,11 @@ use warnings FATAL => qw(all);
 use strict;
 use Binary::Heap::Array;
 Binary::Heap::Array::test();
+
+__END__
+  3.25552797317505,
+  2.36399102210999,
+  1.45935797691345,
+  1.11499309539795,
+]
+# Looks like you planned 483085 tests but ran 11720.
